import React, { useState, useEffect } from 'react'
import NavHeader from '@/components/NavHeader/index'
import Taro from '@tarojs/taro'
import request, { apis } from '@/utils/request'
import { useModel } from '@/store'
import Page from '@/layouts'
import '@/assets/css/reset.less'
import '@/assets/css/iconfont.less'
import './index.less'

export default function WoDe () {

  const { user, setUser } = useModel('user')
  const [UserTab] = useState([
    { icon: 'iconrenzheng1', name: '业主认证', id: 1, router: '/pages/WoDe/WoDeRenZheng/index' },
    { icon: 'iconjifenguize', name: '积分明细', id: 2, router: '/pages/FuLi/JiFenMingXi/index' },
    { icon: 'iconjiaofei', name: '物业缴费', id: 3, router: '/pages/WoDe/WoDeJiaoFei/index' },
    { icon: 'iconfuwu1', name: '物业报修', id: 4, router: '/pages/WoDe/WoDeGongDan/index' }
  ])
  const [MoreUserTab] = useState([
    { icon: 'iconerweima', name: '推荐二维码', id: 5, router: '/pages/WoDe/TuiJianErWeiMa/index' },
    // { icon: 'iconfenxiang', name: '推荐分享', id: 6, router: '/pages/WoDe/TuiJianFenXiang/index' },
    { icon: 'iconhuodong', name: '参与活动', id: 7, router: '/pages/WoDe/WoDeHuoDong/index' },
    { icon: 'icondingdan', name: '我的订单', id: 7, router: '/pages/WoDe/WoDeDingDan/index' }
  ])
  const [DataLock, setDataLock] = useState(false)

  useEffect(() => {
    if (user !== null) {
      request({ ...apis.getUserInfo }).then((res) => {
        setUser({ ...user, ...res })
      }).catch((res) => {
        Taro.showToast({ title: res, icon: 'none' })
      })
    }
  }, [])

  const ToSign = () => { // 签到
    if (DataLock || (user.havaSigned !== undefined && user.havaSigned - 0 === 1)) return
    setDataLock(true)
    request({ ...apis.userSign }).then(() => {
      Taro.showToast({ title: '签到成功', icon: 'none' })
      setUser({ ...user, havaSigned: 1 })
      setDataLock(false)
    }).catch((res) => {
      Taro.showToast({ title: res, icon: 'none' })
      setDataLock(false)
    })
  }

  return (
    <Page>
      <view className='WoDe'>
        <NavHeader BgColor='none' Title='我的' IsFixed={true}></NavHeader>
        <view className='WoDeContent'>

          {/* 顶部背景图 */}
          <view className='TopBg'>
            <view className='ColorBg'></view>
            <view className='UserInfo flex-h'>
              <view className='Icon' onClick={() => { Taro.navigateTo({ url: '/pages/WoDe/GeRenXinXi/index' }) }}>
                <image mode='aspectFill' src={user.avatarurl} class='centerLabel'></image>
              </view>
              <view className='flex-item' onClick={() => { Taro.navigateTo({ url: '/pages/WoDe/GeRenXinXi/index' }) }}>
                <text>{user.nickname || '暂未授权用户信息'}</text>
                <text>{user.phone || '暂未授权手机号'}</text>
              </view>
              {
                user.havaSigned !== undefined &&
                <text onClick={ToSign}>{user.havaSigned - 0 === 1 ? '已签到' : '签到'}</text>
              }
            </view>
          </view>

          {/* 用户选项 */}
          <view className='UserTab'>
            {
              UserTab.map((item, index) => (
                <view key={`UserTab-${index}`} className='flex-h' onClick={() => { Taro.navigateTo({ url: item.router }) }}>
                  <text className={`iconfont ${item.icon}`}></text>
                  <view className='flex-h flex-item'>
                    <text className='flex-item'>{item.name}</text>
                    <text className='iconfont iconjiantouright'></text>
                  </view>
                </view>
              ))
            }
            <view className='Line'></view>
            {
              MoreUserTab.map((item, index) => (
                <view key={`UserTab-${index}`} className='flex-h' onClick={() => { Taro.navigateTo({ url: item.router }) }}>
                  <text className={`iconfont ${item.icon}`}></text>
                  <view className='flex-h flex-item'>
                    <text className='flex-item'>{item.name}</text>
                    <text className='iconfont iconjiantouright'></text>
                  </view>
                </view>
              ))
            }
          </view>

        </view>
      </view>
    </Page>
  )
}
